==> dao_analyzer-0.8.3.dev31-py3-none-any.whl: dao_analyzer/apps/aragon/resources/strings.py <==
"""
   Descp: This file is used to store Aragon app's text.

   Created on: 16-oct-2020

   Copyright 2020-2021 Youssef 'FRYoussef' El Faqir El Rhazoui
        <f.r.youssef@hotmail.com>
"""

TEXT: dict = {
    'approved_votes': 'Approved votes',
    'css_pane_border': 'aragon-border',
    'css_id_app': 'aragon-apps',
    'css_id_assets': 'aragon-assets',
    'css_id_cast': 'aragon-casts',
    'css_id_activity': 'aragon-activity',
    'css_id_organization': 'aragon-organization',
    'css_id_token_holder': 'aragon-token-holders',
    'css_id_transactions': 'aragon-transactions',
    'css_id_vote': 'aragon-votes',
    'dp_id_active_token_holders': 'aragon-dp-token',
    'dp_id_assets': 'aragon-dp-assets',
    'dp_id_new_votes': 'aragon-dp-votes',
    'dp_title_assets': 'Assets',
    'dp_title_active_token_holders': 'Active Holders',
    'dp_title_new_votes': 'New Proposals',
    'pane_css_prefix': 'aragon-pane',
    'rejected_votes': 'Rejected votes',
    'title_active_organization': 'Months which the DAO has registered activity',
    'title_active_token_holders': 'Active token holders',
    'title_active_voters': 'Active voters',
    'title_assets': 'Assets',
    'title_assets_value': 'Tokens with fiat equivalence (USD)',
    'title_assets_novalue': 'Tokens without fiat equivalence',
    'title_casted_votes_for_rate': 'Casted votes-for rate',
    'title_casted_votes_against_rate': 'Casted votes-against rate',
    'title_rate_vote_rate': 'Approval vote rate',
    'title_cast_type': 'Casted votes by support',
    'title_installed_apps': 'Installed apps',
    'title_new_transactions': 'New transactions',
    'title_new_votes': 'New votes',
    'title_section_activity': 'Activity',
    'title_section_token_holders': 'Token Holders',
    'title_section_vote': 'Votes',
    'title_section_cast': 'Casted votes',
    'title_section_transaction': 'Transactions',
    'title_section_app': 'Aragon apps',
    'title_vote_outcome': 'Vote\'s outcome',
    'title_votes_voters': 'NUmber of casted votes per voter',
    'votes_against': 'Casted votes against',
    'votes_for': 'Casted votes for',
}

==> dao_analyzer-1.0.2.dev16-py3-none-any.whl: dao_analyzer/apps/aragon/resources/strings.py <==
"""
   Descp: This file is used to store Aragon app's text.

   Created on: 16-oct-2020

   Copyright 2020-2021 Youssef 'FRYoussef' El Faqir El Rhazoui
        <f.r.youssef@hotmail.com>
"""

TEXT: dict = {
    'approved_votes': 'Approved votes',
    'css_pane_border': 'aragon-border',
    'css_id_app': 'aragon-apps',
    'css_id_assets': 'aragon-assets',
    'css_id_cast': 'aragon-casts',
    'css_id_activity': 'aragon-activity',
    'css_id_organization': 'aragon-organization',
    'css_id_token_holder': 'aragon-token-holders',
    'css_id_transactions': 'aragon-transactions',
    'css_id_vote': 'aragon-votes',
    'disclaimer_activity': 'As activity we consider new proposals, votes and transactions',
    'disclaimer_assets': 'Assets from the Recovery Vault of the DAO',
    'dp_id_active_token_holders': 'aragon-dp-token',
    'dp_id_assets': 'aragon-dp-assets',
    'dp_id_new_votes': 'aragon-dp-votes',
    'dp_id_total_token_holders': 'aragon-dp-holders',
    'dp_title_assets': 'Treasury',
    'dp_title_active_token_holders': 'Active Holders',
    'dp_title_new_votes': 'New Proposals',
    'dp_title_total_token_holders': 'Holders',
    'pane_css_prefix': 'aragon-pane',
    'rejected_votes': 'Rejected votes',
    'title_active_organization': 'Number of DAOs active per month',
    'title_active_token_holders': 'Active token holders',
    'title_active_voters': 'Active voters',
    'title_assets': 'Assets',
    'title_assets_value': 'Tokens with fiat equivalence (USD)',
    'title_assets_novalue': 'Tokens without fiat equivalence',
    'title_casted_votes_for_rate': 'Casted votes-for rate',
    'title_casted_votes_against_rate': 'Casted votes-against rate',
    'title_rate_vote_rate': 'Approval vote rate',
    'title_cast_type': 'Casted votes by support',
    'title_installed_apps': 'Installed apps',
    'title_new_transactions': 'New transactions',
    'title_new_votes': 'New votes',
    'title_organization_activity': 'Total activity per month',
    'title_section_activity': 'Activity',
    'title_section_token_holders': 'Token Holders',
    'title_section_vote': 'Votes',
    'title_section_cast': 'Casted votes',
    'title_section_transaction': 'Transactions',
    'title_section_app': 'Aragon apps',
    'title_total_token_holders': 'Total token holders',
    'title_vote_outcome': 'Vote\'s outcome',
    'title_votes_voters': 'NUmber of casted votes per voter',
    'votes_against': 'Casted votes against',
    'votes_for': 'Casted votes for',
}
